editor = 'open {} -a /Applications/iA\ Writer.app'
compass_path = '/Library/Ruby/Gems/1.8/gems/compass-0.12.2/frameworks/compass/stylesheets/'
deploy_command = 's3cmd put --recursive _public/ s3://www.juanpatten.com'


import os, sys
try:
    cwd = os.getcwd()
    sys.path.append(cwd)
    from config_local import *
except:
    pass



import sys

commands = {}
args = []
kwargs = {}


def EXIT(msg, code=1):
    print(msg)
    sys.exit(code)

def command(fn):
    commands[fn.__name__] = fn
    return fn


def run():
    if len(sys.argv) < 2:
        EXIT('Valid commands are:\n ' + '\n '.join(commands))

    cmd = sys.argv[1]

    if cmd not in commands:
        EXIT('Unkown command')

    args = [x for x in sys.argv[2:] if '=' not in x]
    kwargs = dict([x.split('=') for x in sys.argv[2:] if '=' in x])
    kwargs = dict([(k.replace('-', ''),v) for k,v in kwargs.items()])

    commands[cmd](*args, **kwargs)



from setuptools import setup

requires = open('requirements.txt').read().split('\n')

setup(
    name = 'unn',
    version = '0.0.12',
    packages = ['unn',],
    scripts = ['unn/unn'],
    license = 'MIT',
    install_requires = requires,
    long_description = open('README.md').read(),
)
